Functions
- canonical_
reference_ instance_ key - canonical_
reference_ key - Canonical key (host,
org_path, repo) all lowercased, without .git - get_
host_ from_ url - Extract host from SSH/HTTPS URLs
- is_
git_ url - Return true if string looks like a git URL we support
- is_
https_ url - True if URL starts with https://
- is_
ssh_ url - True if the URL uses SSH schemes we do not support in MCP
- sanitize_
mount_ name - Sanitize a mount name for use as directory name
- validate_
pinned_ ref_ full_ name - validate_
pinned_ ref_ full_ name_ new_ input - validate_
reference_ url - Validate that a reference URL is well-formed and points to org/repo (repo-level only)
- validate_
reference_ url_ https_ only - Validate MCP
add_referenceinput: