pub struct ActiveDocuments {
pub base: String,
pub files: Vec<DocumentInfo>,
}Expand description
Result of listing documents in the active work directory.
Fields
base: Stringfiles: Vec<DocumentInfo>Trait Implementations
Sourceimpl Clone for ActiveDocuments
impl Clone for ActiveDocuments
Sourcefn clone(&self) -> ActiveDocuments
fn clone(&self) -> ActiveDocuments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActiveDocuments
impl Debug for ActiveDocuments
Sourceimpl<'de> Deserialize<'de> for ActiveDocuments
impl<'de> Deserialize<'de> for ActiveDocuments
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActiveDocuments
impl JsonSchema for ActiveDocuments
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ActiveDocuments
impl Serialize for ActiveDocuments
Sourceimpl TextFormat for ActiveDocuments
impl TextFormat for ActiveDocuments