pub struct DocumentInfo {
pub path: String,
pub doc_type: String,
pub size: u64,
pub modified: String,
}Expand description
Metadata about a single document file.
Fields
path: Stringdoc_type: Stringsize: u64modified: StringTrait Implementations
Sourceimpl Clone for DocumentInfo
impl Clone for DocumentInfo
Sourcefn clone(&self) -> DocumentInfo
fn clone(&self) -> DocumentInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocumentInfo
impl Debug for DocumentInfo
Sourceimpl<'de> Deserialize<'de> for DocumentInfo
impl<'de> Deserialize<'de> for DocumentInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DocumentInfo
impl JsonSchema for DocumentInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DocumentInfo
impl RefUnwindSafe for DocumentInfo
impl Send for DocumentInfo
impl Sync for DocumentInfo
impl Unpin for DocumentInfo
impl UnsafeUnpin for DocumentInfo
impl UnwindSafe for DocumentInfo