pub struct WriteDocumentOk {
pub path: String,
pub bytes_written: u64,
}Expand description
Result of successfully writing a document.
Fields
path: Stringbytes_written: u64Trait Implementations
Sourceimpl Clone for WriteDocumentOk
impl Clone for WriteDocumentOk
Sourcefn clone(&self) -> WriteDocumentOk
fn clone(&self) -> WriteDocumentOk
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WriteDocumentOk
impl Debug for WriteDocumentOk
Sourceimpl<'de> Deserialize<'de> for WriteDocumentOk
impl<'de> Deserialize<'de> for WriteDocumentOk
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WriteDocumentOk
impl JsonSchema for WriteDocumentOk
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for WriteDocumentOk
impl Serialize for WriteDocumentOk
Sourceimpl TextFormat for WriteDocumentOk
impl TextFormat for WriteDocumentOk