pub struct RemoteRef {
pub name: String,
pub oid: Option<String>,
pub peeled: Option<String>,
pub target: Option<String>,
}Fields
name: Stringoid: Option<String>peeled: Option<String>target: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RemoteRef
impl<'de> Deserialize<'de> for RemoteRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RemoteRef
impl JsonSchema for RemoteRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for RemoteRef
impl StructuralPartialEq for RemoteRef