pub struct AddReferenceOk {
pub url: String,
pub org: String,
pub repo: String,
pub mount_path: String,
pub mount_target: String,
pub mapping_path: Option<String>,
pub already_existed: bool,
pub config_updated: bool,
pub cloned: bool,
pub mounted: bool,
pub warnings: Vec<String>,
}Fields
url: Stringorg: Stringrepo: Stringmount_path: Stringmount_target: Stringmapping_path: Option<String>already_existed: boolconfig_updated: boolcloned: boolmounted: boolwarnings: Vec<String>Trait Implementations
Sourceimpl Clone for AddReferenceOk
impl Clone for AddReferenceOk
Sourcefn clone(&self) -> AddReferenceOk
fn clone(&self) -> AddReferenceOk
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddReferenceOk
impl Debug for AddReferenceOk
Sourceimpl<'de> Deserialize<'de> for AddReferenceOk
impl<'de> Deserialize<'de> for AddReferenceOk
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddReferenceOk
impl JsonSchema for AddReferenceOk
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AddReferenceOk
impl Serialize for AddReferenceOk
Sourceimpl TextFormat for AddReferenceOk
impl TextFormat for AddReferenceOk