pub struct RepoRefsList {
pub url: String,
pub total: usize,
pub truncated: bool,
pub entries: Vec<RemoteRef>,
}Fields
url: Stringtotal: usizetruncated: boolentries: Vec<RemoteRef>Trait Implementations
Sourceimpl Clone for RepoRefsList
impl Clone for RepoRefsList
Sourcefn clone(&self) -> RepoRefsList
fn clone(&self) -> RepoRefsList
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RepoRefsList
impl Debug for RepoRefsList
Sourceimpl<'de> Deserialize<'de> for RepoRefsList
impl<'de> Deserialize<'de> for RepoRefsList
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RepoRefsList
impl JsonSchema for RepoRefsList
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RepoRefsList
impl Serialize for RepoRefsList
Sourceimpl TextFormat for RepoRefsList
impl TextFormat for RepoRefsList