pub struct TemplateResponse {
pub template_type: TemplateType,
}Fields
template_type: TemplateTypeTrait Implementations
Sourceimpl Clone for TemplateResponse
impl Clone for TemplateResponse
Sourcefn clone(&self) -> TemplateResponse
fn clone(&self) -> TemplateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemplateResponse
impl Debug for TemplateResponse
Sourceimpl<'de> Deserialize<'de> for TemplateResponse
impl<'de> Deserialize<'de> for TemplateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TemplateResponse
impl JsonSchema for TemplateResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for TemplateResponse
impl Serialize for TemplateResponse
Sourceimpl TextFormat for TemplateResponse
impl TextFormat for TemplateResponse