pub fn get_mount_manager(
platform_info: &PlatformInfo,
) -> Result<Box<dyn MountManager>>Expand description
Factory function to get the appropriate mount manager for the current platform
pub fn get_mount_manager(
platform_info: &PlatformInfo,
) -> Result<Box<dyn MountManager>>Factory function to get the appropriate mount manager for the current platform