pub struct FileLock {
pub path: PathBuf,
/* private fields */
}Expand description
RAII advisory file lock.
The lock is automatically released when this struct is dropped. Uses advisory locking via std, which works across processes on Unix systems.
Fields
path: PathBufImplementations